@@ -1,4 +1,4 @@
-;;; dectalk-voices.el --- Define various device independent voices in terms of Dectalk codes.  -*- lexical-binding: t; -*-
+;;; dectalk-voices.el --- Define various device independent voices in terms of Dectalk codes  -*- lexical-binding: t; -*-
 ;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Module to set up Dectalk voices and personalities
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2015, T. V. Raman
+;;;Copyright (C) 1995 -- 2017, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -53,6 +53,19 @@
 (require 'acss-structure)
 (require 'tts)
 
+;;}}}
+;;{{{ Customizations:
+;;;###autoload
+(defcustom dectalk-default-speech-rate 225
+  "*Default speech rate at which TTS is started. "
+  :group 'tts
+  :type 'integer
+  :set #'(lambda(sym val)
+           (set-default sym val)
+           (when (and (getenv "DTK_PROGRAM")
+                      (string-match "dtk" (getenv "DTK_PROGRAM")))
+           (setq-default dtk-speech-rate val))))
+
 ;;}}}
 ;;{{{  Top-level TTS  switcher
 
@@ -72,7 +85,7 @@
 ;;; From dtk-speak.el:
 
 (defvar tts-default-speech-rate)
-(defvar dectalk-default-speech-rate)
+
 (defvar dtk-speech-rate-step)
 (defvar dtk-speech-rate-base)
 
@@ -86,14 +99,14 @@
   "Association between symbols and strings to set Dectalk voices.
 The string can set any Dectalk parameter.")
 
-(defsubst dectalk-define-voice (name command-string)
+(defun dectalk-define-voice (name command-string)
   "Define a Dectalk voice named NAME.
 This voice will be set   by sending the string
 COMMAND-STRING to the Dectalk."
   (declare (special dectalk-voice-table))
   (puthash  name command-string  dectalk-voice-table))
 
-(defsubst dectalk-get-voice-command (name)
+(defun dectalk-get-voice-command (name)
   "Retrieve command string for  voice NAME."
   (declare (special dectalk-voice-table))
   (cond
@@ -102,7 +115,7 @@ COMMAND-STRING to the Dectalk."
    (t (or  (gethash name dectalk-voice-table)
            dectalk-default-voice-string))))
 
-(defsubst dectalk-voice-defined-p (name)
+(defun dectalk-voice-defined-p (name)
   "Check if there is a voice named NAME defined."
   (declare (special dectalk-voice-table))
   (gethash name dectalk-voice-table))
@@ -135,7 +148,7 @@ COMMAND-STRING to the Dectalk."
 (defvar dectalk-family-table nil
   "Association list of Dectalk voice names and control codes.")
 
-(defsubst dectalk-set-family-code (name code)
+(defun dectalk-set-family-code (name code)
   "Set control code for voice family NAME  to CODE."
   (declare (special dectalk-family-table))
   (when (stringp name)
@@ -144,7 +157,7 @@ COMMAND-STRING to the Dectalk."
         (cons (list name code)
               dectalk-family-table)))
 
-(defsubst dectalk-get-family-code (name)
+(defun dectalk-get-family-code (name)
   "Get control code for voice family NAME."
   (declare (special dectalk-family-table))
   (when (stringp name)
@@ -170,7 +183,7 @@ COMMAND-STRING to the Dectalk."
 Keys are symbols of the form <FamilyName-Dimension>.
 Values are vectors holding the control codes for the 10 settings.")
 
-(defsubst dectalk-css-set-code-table (family dimension table)
+(defun dectalk-css-set-code-table (family dimension table)
   "Set up voice FAMILY.
 Argument DIMENSION is the dimension being set,
 and TABLE gives the values along that dimension."
@@ -178,7 +191,7 @@ and TABLE gives the values along that dimension."
   (let ((key (intern (format "%s-%s" family dimension))))
     (puthash  key table dectalk-css-code-tables)))
 
-(defsubst dectalk-css-get-code-table (family dimension)
+(defun dectalk-css-get-code-table (family dimension)
   "Retrieve table of values for specified FAMILY and DIMENSION."
   (declare (special dectalk-css-code-tables))
   (let ((key (intern (format "%s-%s" family dimension))))
@@ -281,7 +294,7 @@ and TABLE gives the values along that dimension."
 
 ;;}}}
 
-(defsubst dectalk-get-average-pitch-code (value family)
+(defun dectalk-get-average-pitch-code (value family)
   "Get  AVERAGE-PITCH for specified VALUE and  FAMILY."
   (or family (setq family 'paul))
   (if value
@@ -376,7 +389,7 @@ and TABLE gives the values along that dimension."
   (dectalk-css-set-code-table 'betty 'pitch-range table))
 
 ;;}}}
-(defsubst dectalk-get-pitch-range-code (value family)
+(defun dectalk-get-pitch-range-code (value family)
   "Get pitch-range code for specified VALUE and FAMILY."
   (or family (setq family 'paul))
   (if value
@@ -480,7 +493,7 @@ and TABLE gives the values along that dimension."
   (dectalk-css-set-code-table 'betty 'stress table))
 
 ;;}}}
-(defsubst dectalk-get-stress-code (value family)
+(defun dectalk-get-stress-code (value family)
   (or family (setq family 'paul))
   (if value
       (aref (dectalk-css-get-code-table family 'stress)
@@ -569,7 +582,7 @@ and TABLE gives the values along that dimension."
 
 ;;}}}
 
-(defsubst dectalk-get-richness-code (value family)
+(defun dectalk-get-richness-code (value family)
   (or family (setq family 'paul))
   (if value
       (aref (dectalk-css-get-code-table family 'richness)
@@ -579,7 +592,7 @@ and TABLE gives the values along that dimension."
 ;;}}}
 ;;{{{  punctuations
 
-(defsubst dectalk-get-punctuations-code (value)
+(defun dectalk-get-punctuations-code (value)
   "Return string needed to set specified punctuations mode."
   (if value
       (format " :pu %s " value)
@@ -615,7 +628,7 @@ and TABLE gives the values along that dimension."
 (defun dectalk-list-voices ()
   "List defined voices."
   (declare (special dectalk-voice-table))
-  (loop for k being the hash-keys of dectalk-voice-table
+  (cl-loop for k being the hash-keys of dectalk-voice-table
         collect   k))
 
 ;;}}}
