@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{ Copyright:
-;;;Copyright (C) 1995 -- 2015, T. V. Raman
+;;;Copyright (C) 1995 -- 2017, T. V. Raman
 ;;; Copyright (c) 1995 by .
 ;;; All Rights Reserved.
 ;;;
@@ -92,11 +92,11 @@
 (defadvice ediff-setup-control-buffer (after emacspeak pre act)
   (setq emacspeak-ediff-control-buffer (ad-get-arg 0)))
 
-(defsubst emacspeak-ediff-control-panel ()
+(defun emacspeak-ediff-control-panel ()
   (declare (special emacspeak-ediff-control-buffer))
   emacspeak-ediff-control-buffer)
 
-(defsubst emacspeak-ediff-difference-a-overlay (n)
+(defun emacspeak-ediff-difference-a-overlay (n)
   (declare (special ediff-difference-vector-A
                     ediff-number-of-differences))
   (assert (< n ediff-number-of-differences) t
@@ -104,7 +104,7 @@
           ediff-number-of-differences)
   (aref (aref ediff-difference-vector-A n) 0))
 
-(defsubst emacspeak-ediff-difference-b-overlay (n)
+(defun emacspeak-ediff-difference-b-overlay (n)
   (declare (special ediff-difference-vector-B
                     ediff-number-of-differences))
   (assert (< n ediff-number-of-differences) t
@@ -112,7 +112,7 @@
           ediff-number-of-differences)
   (aref (aref ediff-difference-vector-B n) 0))
 
-(defsubst emacspeak-ediff-difference-c-overlay (n)
+(defun emacspeak-ediff-difference-c-overlay (n)
   (declare (special ediff-difference-vector-B
                     ediff-difference-vector-C
                     ediff-number-of-differences))
@@ -121,7 +121,7 @@
           ediff-number-of-differences)
   (aref (aref ediff-difference-vector-C n) 0))
 
-(defsubst emacspeak-ediff-fine-difference-a-overlays (n)
+(defun emacspeak-ediff-fine-difference-a-overlays (n)
   (declare (special ediff-difference-vector-A
                     ediff-number-of-differences))
   (assert (< n ediff-number-of-differences) t
@@ -129,7 +129,7 @@
           ediff-number-of-differences)
   (aref (aref ediff-difference-vector-A n) 1))
 
-(defsubst emacspeak-ediff-fine-difference-b-overlays (n)
+(defun emacspeak-ediff-fine-difference-b-overlays (n)
   (declare (special ediff-difference-vector-B
                     ediff-number-of-differences))
   (assert (< n ediff-number-of-differences) t
@@ -137,7 +137,7 @@
           ediff-number-of-differences)
   (aref (aref ediff-difference-vector-B n) 1))
 
-(defsubst emacspeak-ediff-fine-difference-c-overlays (n)
+(defun emacspeak-ediff-fine-difference-c-overlays (n)
   (declare (special ediff-difference-vector-B
                     ediff-difference-vector-C
                     ediff-number-of-differences))
@@ -146,16 +146,16 @@
           ediff-number-of-differences)
   (aref (aref ediff-difference-vector-C n) 1))
 
-(defsubst emacspeak-ediff-difference-fine-diff (difference)
+(defun emacspeak-ediff-difference-fine-diff (difference)
   (aref difference 2))
 
 ;;}}}
 ;;{{{ Diff Overlay Accessors:
 
-(defsubst emacspeak-ediff-diff-overlay-from-difference (diff counter)
+(defun emacspeak-ediff-diff-overlay-from-difference (diff counter)
   (aref (aref diff counter) 0))
 
-(defsubst emacspeak-ediff-fine-overlays-from-difference (diff counter)
+(defun emacspeak-ediff-fine-overlays-from-difference (diff counter)
   (aref (aref diff counter) 1))
 
 ;;}}}
