@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2015, T. V. Raman
+;;; Copyright (C) 1995 -- 2017, T. V. Raman
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -71,7 +71,7 @@
 ;;}}}
 ;;{{{ helpers 
 
-(defsubst emacspeak-eperiodic-name-element-at-point ()
+(defun emacspeak-eperiodic-name-element-at-point ()
   "Returns name of current element."
   (declare (special eperiodic-element-properties))
   (let ((name 
