@@ -1,4 +1,4 @@
-;;; emacspeak-fix-interactive.el --- Tools to make  Emacs' builtin prompts   speak  -*- lexical-binding: t; -*-
+;;; emacspeak-fix-interactive.el --- Make  Emacs' builtin prompts   speak  -*- lexical-binding: t; -*-
 ;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description: Fixes functions that use interactive to prompt for args.
@@ -16,7 +16,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2015, T. V. Raman
+;;;Copyright (C) 1995 -- 2017, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -65,7 +65,7 @@
    "\\|^color\\|^timer")
   "Regular expression matching function names whose interactive spec should not be fixed.")
 ;;;###autoload
-(defsubst emacspeak-should-i-fix-interactive-p  (sym)
+(defun emacspeak-should-i-fix-interactive-p  (sym)
   "Predicate to test if this function should be fixed. "
   (and
    (not (string-match emacspeak-commands-dont-fix-regexp
@@ -82,7 +82,7 @@
 
 ;;}}}
 
-(defsubst ems-prompt-without-minibuffer-p (prompt)
+(defun ems-prompt-without-minibuffer-p (prompt)
   "Check if this interactive prompt uses the minibuffer."
   (string-match  "^\*?[ckK]" prompt))
 
@@ -164,7 +164,7 @@ use the minibuffer."
                   (get (cdr item) 'byte-compile)))
          (commandp (cdr item))
          (emacspeak-fix-interactive-command-if-necessary (cdr item))))
-  (when (ems-interactive-p)
+  (when (called-interactively-p 'interactive)
     (message "Fixed interactive commands defined in module %s" module)))
 
 (defvar emacspeak-load-history-pointer nil
@@ -185,12 +185,12 @@ Memoizes call in emacspeak-load-history-pointer to memoize this call. "
                   (not (eq lh emacspeak-load-history-pointer)))
 ;;; fix commands in this module
         (emacspeak-fix-commands-loaded-from lh)
-        (when (ems-interactive-p)
+        (when (called-interactively-p 'interactive)
           (message "Fixed commands in %s" (first (first lh))))
         (setq lh (rest lh)))
 ;;;memoize for future call
       (setq emacspeak-load-history-pointer load-history))
-    (when (ems-interactive-p)
+    (when (called-interactively-p 'interactive)
       (message "Fixed recently defined  interactive commands")))
   t)
 
