@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2015, T. V. Raman
+;;;Copyright (C) 1995 -- 2017, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -69,7 +69,7 @@
 ;;}}}
 ;;{{{ Advice interactive commands.
 
-(loop
+(cl-loop
  for  f in
  '(flycheck-next-error flycheck-previous-error
                        flycheck-first-error)
