@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2015, T. V. Raman
+;;; Copyright (c) 1995 -- 2017, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -50,9 +50,9 @@
 ;;}}}
 ;;{{{ helper functions
 
-(defsubst gomoku-point-x ()
+(defun gomoku-point-x ()
   (gomoku-index-to-x (gomoku-point-square)))
-(defsubst emacspeak-gomoku-cell-value (row column)
+(defun emacspeak-gomoku-cell-value (row column)
   (declare (special gomoku-board))
   (aref  gomoku-board
          (gomoku-xy-to-index column row)))
@@ -88,7 +88,7 @@
   (let ((row (gomoku-point-y))
         (values nil))
     (setq values
-          (loop for i from 1 to gomoku-board-width
+          (cl-loop for i from 1 to gomoku-board-width
                 collect 
                 (case (emacspeak-gomoku-cell-value row i)
                   (0 "-")
@@ -104,7 +104,7 @@
   (let ((column (gomoku-point-x))
         (values nil))
     (setq values
-          (loop for i from 1 to gomoku-board-height
+          (cl-loop for i from 1 to gomoku-board-height
                 collect 
                 (case (emacspeak-gomoku-cell-value i column)
                   (0 "-")
@@ -134,7 +134,7 @@
       (setq diag-start-x  1
             diag-start-y (+ 1 (- row column)))))
     (setq values
-          (loop for i from diag-start-y  to gomoku-board-height
+          (cl-loop for i from diag-start-y  to gomoku-board-height
                 and j from diag-start-x to gomoku-board-width 
                 collect
                 (case (emacspeak-gomoku-cell-value i j)
@@ -168,7 +168,7 @@
       (setq diag-start-y
             (- (+ row column) diag-start-x))))
     (setq values
-          (loop for i from diag-start-y  to gomoku-board-height
+          (cl-loop for i from diag-start-y  to gomoku-board-height
                 and j downfrom   diag-start-x  to 1 
                 collect
                 (case (emacspeak-gomoku-cell-value i j)
@@ -247,7 +247,7 @@
         'gomoku-move-sw)
   "Commands in gomoku that navigate the board")
 ;;; generated by:
-                                        ;(loop for command in
+                                        ;(cl-loop for command in
                                         ;      emacspeak-gomoku-navigation-commands
                                         ;      do
                                         ;      (insert
@@ -350,10 +350,10 @@
 (defun emacspeak-gomoku-setup-keys ()
   "Add additional keybindings"
   (declare (special gomoku-mode-map))
-  (loop for key in (where-is-internal 'backward-char (list gomoku-mode-map))
+  (cl-loop for key in (where-is-internal 'backward-char (list gomoku-mode-map))
         do
         (define-key gomoku-mode-map key 'gomoku-move-left))
-  (loop for key in (where-is-internal 'forward-char (list gomoku-mode-map))
+  (cl-loop for key in (where-is-internal 'forward-char (list gomoku-mode-map))
         do
         (define-key gomoku-mode-map key 'gomoku-move-right))
   (define-key gomoku-mode-map "\t"
