@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2015, T. V. Raman
+;;;Copyright (C) 1995 -- 2017, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -388,7 +388,7 @@ This variable is buffer-local.")
 ;;; prefix: http://www.google.com/url?q=
 ;;; Suffix: &sa=...
 
-(defsubst emacspeak-google-canonicalize-result-url (url)
+(defun emacspeak-google-canonicalize-result-url (url)
   "Strip out the actual result URL from the redirect wrapper."
   (declare (special emacspeak-websearch-google-use-https))
   (url-unhex-string
@@ -396,7 +396,7 @@ This variable is buffer-local.")
               (if emacspeak-websearch-google-use-https 29 28)
               (string-match "&sa=" url))))
 
-(defsubst emacspeak-google-result-url-prefix ()
+(defun emacspeak-google-result-url-prefix ()
   "Return prefix of result urls."
   (declare (special emacspeak-websearch-google-use-https))
   (format "%s://www.google.com/url?q="
@@ -405,7 +405,7 @@ This variable is buffer-local.")
 ;;}}}
 ;;{{{ Interactive Commands
 
-(loop for this-tool in
+(cl-loop for this-tool in
       (emacspeak-google-toolbelt)
       do
       (eval
@@ -456,18 +456,18 @@ This variable is buffer-local.")
                (or emacspeak-google-query
                    (gweb-google-autocomplete))))))))
 
-(defsubst emacspeak-google-toolbelt-names ()
+(defun emacspeak-google-toolbelt-names ()
   "Return memoized cache of names."
   (declare (special emacspeak-google-toolbelt-names))
   (or emacspeak-google-toolbelt-names
       (setq emacspeak-google-toolbelt-names
-            (loop
+            (cl-loop
              for b in emacspeak-google-toolbelt
              collect (emacspeak-google-tool-name b)))))
 
-(defsubst emacspeak-google-toolbelt-names-from-toolbelt (toolbelt)
+(defun emacspeak-google-toolbelt-names-from-toolbelt (toolbelt)
   "Return list of names in toolbelt."
-  (loop
+  (cl-loop
    for b in toolbelt
    collect (emacspeak-google-tool-name b)))
 
@@ -518,7 +518,7 @@ This variable is buffer-local.")
 (define-prefix-command  'emacspeak-google-command
   'emacspeak-google-keymap)
 
-(loop
+(cl-loop
  for k in
  '(
    ("." emacspeak-google-toolbelt-change)("." emacspeak-google-toolbelt-change)
@@ -540,7 +540,7 @@ This variable is buffer-local.")
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
-(loop for f in
+(cl-loop for f in
       '(gmaps-driving-directions gmaps-bicycling-directions
                                  gmaps-walking-directions gmaps-transit-directions
                                  gmaps-places-nearby gmaps-places-search)
@@ -600,11 +600,12 @@ This variable is buffer-local.")
             (read-from-minibuffer
              "Language: " nil nil t nil
              emacspeak-google-tts-default-language))))
-  (start-process
-   "google-tts" nil  emacspeak-m-player-program 
-   (format emacspeak-google-tts-rest-uri
-           (or lang emacspeak-google-tts-default-language)
-           (url-hexify-string  text))))
+  (let ((url (format emacspeak-google-tts-rest-uri
+                     (or lang emacspeak-google-tts-default-language)
+                     (url-hexify-string  text))))
+    (kill-new url)
+    (start-process
+     "google-tts" nil  emacspeak-m-player-program url)))
 
 ;;;###autoload
 (defun emacspeak-google-tts-region (start end)
