@@ -14,7 +14,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2015, T. V. Raman
+;;;Copyright (C) 1995 -- 2017, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -81,7 +81,7 @@ node -- speak the entire node."
           (const :tag "Entire node" node))
   :group 'emacspeak-info)
 
-(defsubst emacspeak-info-speak-current-window ()
+(defun emacspeak-info-speak-current-window ()
   "Speak current window in info buffer."
   (let ((start  (point))
         (window (get-buffer-window (current-buffer))))
@@ -92,7 +92,7 @@ node -- speak the entire node."
 (defun emacspeak-info-visit-node()
   "Apply requested action upon visiting a node."
   (declare (special emacspeak-info-select-node-speak-chunk))
-  (emacspeak-auditory-icon 'select-object)
+  (emacspeak-auditory-icon 'open-object)
   (cond
    ((eq emacspeak-info-select-node-speak-chunk 'screenfull)
     (emacspeak-info-speak-current-window))
@@ -100,7 +100,7 @@ node -- speak the entire node."
     (emacspeak-speak-buffer))
    (t (emacspeak-speak-line))))
 
-(loop
+(cl-loop
  for f in
  '(info info-display-manual Info-select-node
         Info-follow-reference Info-goto-node info-emacs-manual
@@ -173,15 +173,57 @@ See documentation for command `Info-goto-node' for details on
 node-spec."
   (interactive
    (list
-    (let ((completion-ignore-case t))
+    (let ((completion-ignore-case t)
+          (f nil)
+          (n nil))
       (info-initialize)
-      (completing-read "Node: "
-                       (Info-build-node-completions
-                        (completing-read "File: " (info--manual-names nil)
-                                         nil t))))))
+      (setq f (completing-read "File: " (info--manual-names nil) nil t))
+      (setq n (completing-read "Node: " (Info-build-node-completions f)))
+      (format "(%s)%s" f n))))
   (Info-goto-node node-spec)
   (emacspeak-info-visit-node))
 
+;;}}}
+;;{{{ Info: Section navigation
+;;; Use property info-title-* to move across section titles.
+(defvar emacspeak-info--title-faces
+  '(info-title-1 info-title-2 info-title-3 info-title-4 info-menu-header)
+  "Faces that identify section titles.")
+
+(defun emacspeak-info-next-section ()
+  "Move forward to next section in this node."
+  (interactive)
+  (let ((target nil))
+    (save-excursion
+      (while (and (null target)
+                  (not (eobp)))
+        (goto-char (next-single-property-change (point)  'face nil (point-max)))
+        (when (memq (get-text-property (point) 'face) emacspeak-info--title-faces)
+          (setq target (point)))))
+    (cond
+     (target
+      (goto-char target)
+      (emacspeak-speak-line)
+      (emacspeak-auditory-icon 'large-movement))
+     (t (message "No more sections in this node")))))
+
+(defun emacspeak-info-previous-section ()
+  "Move backward to previous section in this node."
+  (interactive)
+  (let ((target nil))
+    (save-excursion
+      (while (and (null target)
+                  (not (bobp)))
+        (goto-char (previous-single-property-change (point)  'face nil (point-min)))
+        (when (memq (get-text-property (point) 'face) emacspeak-info--title-faces)
+          (setq target (line-beginning-position)))))
+    (cond
+     (target
+      (goto-char target)
+      (emacspeak-speak-line)
+      (emacspeak-auditory-icon 'large-movement))
+     (t (message "No previous section in   this node")))))
+
 ;;}}}
 ;;{{{ Speak header line if hidden
 
@@ -205,6 +247,8 @@ node-spec."
 (declaim (special Info-mode-map))
 (define-key Info-mode-map "T" 'emacspeak-info-speak-header)
 (define-key Info-mode-map "'" 'emacspeak-speak-rest-of-buffer)
+(define-key Info-mode-map "\M-n" 'emacspeak-info-next-section)
+(define-key Info-mode-map "\M-p" 'emacspeak-info-previous-section)
 
 ;;}}}
 (provide  'emacspeak-info)
