@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2015, T. V. Raman
+;;; Copyright (c) 1995 -- 2017, T. V. Raman
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -78,6 +78,7 @@
    ))
 ;;}}}
 ;;{{{ Advice interactive commands:
+
 (defadvice jabber-switch-to-roster-buffer (after emacspeak pre act comp)
   "Provide auditory feedback."
   (when (ems-interactive-p)
@@ -87,7 +88,7 @@
 ;;}}}
 ;;{{{ silence keepalive
 
-(loop
+(cl-loop
  for f in
  '(
    image-type jabber-chat-with jabber-chat-with-jid-at-point
@@ -97,11 +98,11 @@
  (eval
   `(defadvice ,f (around emacspeak pre act comp)
      "Silence  messages."
-     (ems-with-messages-silenced ad-do-it
-                                 ad-return-value))))
+     (ems-with-messages-silenced
+      ad-do-it
+      ad-return-value))))
 
 ;;}}}
-
 ;;{{{ jabber activity:
 
 (defadvice jabber-activity-switch-to (after emacspeak pre act comp)
@@ -142,6 +143,7 @@
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
     (message "Set extended  away.")))
+
 (defadvice jabber-go-to-next-jid (after emacspeak pre act comp)
   "Provide auditory feedback."
   (when (ems-interactive-p)
@@ -194,12 +196,11 @@
 
 (defadvice jabber-connect-all (after emacspeak pre act comp)
   "switch to roster so we give it a chance to update."
-  (when (ems-interactive-p)
-    (switch-to-buffer jabber-roster-buffer)))
+  (when (ems-interactive-p) (switch-to-buffer jabber-roster-buffer)))
+
 (defadvice jabber-roster-update (around emacspeak    pre act  comp)
   "Make this operation a No-Op unless the roster is visible."
-  (when (get-buffer-window-list jabber-roster-buffer)
-    ad-do-it))
+  (when (get-buffer-window-list jabber-roster-buffer) ad-do-it))
 
 (defadvice jabber-display-roster (around emacspeak    pre act  comp)
   "Make this operation a No-Op unless called interactively."
@@ -208,7 +209,11 @@
 (add-hook 'jabber-post-connect-hook 'jabber-switch-to-roster-buffer)
 
 ;;}}}
-
+(defun emacspeak-jabber-connected ()
+  "Function to add to jabber-post-connection-hook."
+  (emacspeak-auditory-icon 'task-done)
+  (dtk-notify-say "Connected to jabber."))
+(add-hook 'jabber-post-connect-hook #'emacspeak-jabber-connected)
 ;;}}}
 ;;{{{ Pronunciations
 (declaim (special emacspeak-pronounce-internet-smileys-pronunciations))
@@ -270,7 +275,7 @@ session."
     (goto-char (car extent))))
 
 (when (boundp 'jabber-chat-mode-map)
-  (loop for k in
+  (cl-loop for k in
         '(
           ("M-n" emacspeak-jabber-chat-next-message)
           ("M-p" emacspeak-jabber-chat-previous-message)
