@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2015, T. V. Raman
+;;; Copyright (c) 1995 -- 2017, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -227,7 +227,7 @@
 ;;}}}
 ;;{{{ speech enable jdb interaction 
 
-(loop for command in
+(cl-loop for command in
       '(
         jde-debug-step-into
         jde-debug-step-out
