@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2015, T. V. Raman 
+;;;Copyright (C) 1995 -- 2017, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -71,7 +71,7 @@
 
 ;;}}}
 ;;{{{ advice interactive commands
-(loop for f in
+(cl-loop for f in
       '(muse-follow-name-at-point
         muse-follow-name-at-point-other-window
         muse-next-reference
