@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2015, T. V. Raman
+;;; Copyright (C) 1995 -- 2017, T. V. Raman
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -167,18 +167,18 @@ will be placed."
 (defvar emacspeak-ocr-buffer-name "*ocr*"
   "Name of OCR working buffer.")
 
-(defsubst emacspeak-ocr-get-buffer ()
+(defun emacspeak-ocr-get-buffer ()
   "Return OCR working buffer."
   (get-buffer-create
    (format  "*%s-ocr*"
             (emacspeak-ocr-default-name))))
 
-(defsubst emacspeak-ocr-get-text-name ()
+(defun emacspeak-ocr-get-text-name ()
   "Return name of current text document."
   (declare (special emacspeak-ocr-document-name))
   (format "%s.text" emacspeak-ocr-document-name))
 
-(defsubst emacspeak-ocr-get-image-name (extension)
+(defun emacspeak-ocr-get-image-name (extension)
   "Return name of current image."
   (declare (special emacspeak-ocr-document-name
                     emacspeak-ocr-last-page-number))
@@ -187,7 +187,7 @@ will be placed."
           (1+ emacspeak-ocr-last-page-number)
           extension))
 
-(defsubst emacspeak-ocr-get-page-name ()
+(defun emacspeak-ocr-get-page-name ()
   "Return name of current page."
   (declare (special emacspeak-ocr-document-name
                     emacspeak-ocr-current-page-number))
@@ -205,7 +205,7 @@ will be placed."
     emacspeak-ocr-last-page-number)
   "Mode line format for OCR buffer.")
 
-(defsubst emacspeak-ocr-get-mode-line-format ()
+(defun emacspeak-ocr-get-mode-line-format ()
   "Return string suitable for use as the mode line."
   (declare (special major-mode
                     emacspeak-ocr-current-page-number))
@@ -215,7 +215,7 @@ will be placed."
           emacspeak-ocr-last-page-number
           major-mode))
 
-(defsubst emacspeak-ocr-update-mode-line()
+(defun emacspeak-ocr-update-mode-line()
   "Update mode line for OCR mode."
   (declare (special mode-line-format))
   (setq mode-line-format
@@ -309,7 +309,7 @@ See \\{emacspeak-ocr-mode-map}.
 (define-key emacspeak-ocr-mode-map "I"
   'emacspeak-ocr-set-scan-image-options)
 (define-key emacspeak-ocr-mode-map "C" 'emacspeak-ocr-set-compress-image-options)
-(loop for i from 1 to 9
+(cl-loop for i from 1 to 9
       do
       (define-key emacspeak-ocr-mode-map
         (format "%s" i)
@@ -665,7 +665,7 @@ correctly by themselves."
       (emacspeak-speak-line)
       (emacspeak-auditory-icon 'large-movement))))
 
-(defsubst emacspeak-ocr-goto-page (page)
+(defun emacspeak-ocr-goto-page (page)
   "Move to specified page."
   (declare (special emacspeak-ocr-page-positions))
   (goto-char
