@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2015, T. V. Raman
+;;;Copyright (C) 1995 -- 2017, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -194,8 +194,7 @@ commands. "
     (when (or  emacspeak-outline-dont-query-before-speaking
                (y-or-n-p
                 (format  "Speak %s lines from section %s"
-                         (count-lines start end)
-                         (thing-at-point 'line))))
+                         (count-lines start end) (ems-this-line))))
       (emacspeak-speak-region start end))))
 
 (defun emacspeak-outline-speak-next-heading ()
@@ -241,8 +240,7 @@ except that the outline section is  spoken"
      (or emacspeak-outline-dont-query-before-speaking
          (y-or-n-p
           (format "Speak %s lines from section %s"
-                  (count-lines start end)
-                  (thing-at-point 'line))))
+                  (count-lines start end) (ems-this-line))))
      (emacspeak-speak-region start end))))
 
 ;;{{{ bind these in outline mode
@@ -274,9 +272,9 @@ except that the outline section is  spoken"
   "Provide auditory feedback about the child we zoomed into"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
-    (message "Zoomed into outline %s containing %s lines"
-             (thing-at-point 'line)
-             (count-lines (point-min) (point-max)))))
+    (message
+     "Zoomed into outline %s containing %s lines"
+     (ems-this-line) (count-lines (point-min) (point-max)))))
 
 (defadvice foldout-exit-fold (after emacspeak pre act comp)
   "Provide auditory feedback when exiting a fold"
