@@ -1,4 +1,4 @@
-;;; emacspeak-tetris.el --- Speech enable game of Tetris
+;;; emacspeak-tetris.el --- Speech enable game of Tetris  -*- lexical-binding: t; -*-
 ;;; $Id$
 ;;; $Author: tv.raman.tv $ 
 ;;; Description: Auditory interface to tetris
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2015, T. V. Raman
+;;; Copyright (c) 1995 -- 2017, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -97,11 +97,11 @@
 (aset emacspeak-tetris-shape-name-table 5 " s ")
 (aset emacspeak-tetris-shape-name-table 6 " inverted t ")
 (aset emacspeak-tetris-shape-name-table 7 " line ")
-(defsubst emacspeak-tetris-blank-row ()
+(defun emacspeak-tetris-blank-row ()
   (declare (special tetris-width))
   (make-string tetris-width  0))
 
-(defsubst emacspeak-tetris-shape-name (tile)
+(defun emacspeak-tetris-shape-name (tile)
   (declare (special emacspeak-tetris-shape-name-table))
   (aref emacspeak-tetris-shape-name-table tile))
 
@@ -110,7 +110,7 @@
 ;;;we need this because in the new version a line is not a row (on the
 ;;;bottom)
 
-(defsubst emacspeak-tetris-get-current-row ()
+(defun emacspeak-tetris-get-current-row ()
   (declare (special tetris-border))
   (save-excursion
     (beginning-of-line)
@@ -121,7 +121,7 @@
       (while (not (= (following-char) tetris-border)) (forward-char 1))
       (buffer-substring start (point)))))
 
-(defsubst emacspeak-tetris-speak-row ()
+(defun emacspeak-tetris-speak-row ()
   "Speak current tetris row"
   (interactive)
   (dtk-speak (emacspeak-tetris-get-current-row)))
@@ -130,7 +130,7 @@
   "Speak where on the tetris board we are"
   (interactive)
   (emacspeak-speak-line-number))
-(defsubst emacspeak-tetris-speak-x-coordinate ()
+(defun emacspeak-tetris-speak-x-coordinate ()
   "Speak current position"
   (interactive)
   (declare  (special tetris-pos-x
@@ -139,7 +139,7 @@
            (emacspeak-tetris-shape-name (1+ tetris-shape))
            tetris-pos-x))
 
-(defsubst emacspeak-tetris-speak-coordinates ()
+(defun emacspeak-tetris-speak-coordinates ()
   "Speak current position"
   (interactive)
   (declare  (special tetris-pos-x tetris-pos-y
@@ -148,7 +148,7 @@
            (emacspeak-tetris-shape-name (1+ tetris-shape))
            tetris-pos-x tetris-pos-y))
 
-(defsubst emacspeak-tetris-speak-current-shape ()
+(defun emacspeak-tetris-speak-current-shape ()
   "Speak current shape"
   (interactive)
   (declare (special tetris-shape tetris-rot
@@ -165,7 +165,7 @@
   (if emacspeak-tetris-filled-a-row
       (setq  emacspeak-tetris-filled-a-row nil)))
 
-(defsubst emacspeak-tetris-speak-next-shape ()
+(defun emacspeak-tetris-speak-next-shape ()
   "Speak next shape"
   (interactive)
   (declare (special tetris-next-shape))
@@ -173,7 +173,7 @@
    (format "%s "
            (emacspeak-tetris-shape-name (1+ tetris-next-shape)))))
 
-(defsubst emacspeak-tetris-speak-current-shape-and-coordinates ()
+(defun emacspeak-tetris-speak-current-shape-and-coordinates ()
   "Speak shape orientation and coordinates"
   (interactive)
   (declare (special  tetris-pos-x tetris-pos-y
@@ -184,7 +184,7 @@
            tetris-pos-y
            tetris-rot))
 
-(defsubst emacspeak-tetris-speak-score()
+(defun emacspeak-tetris-speak-score()
   "Speak the score"
   (interactive)
   (declare (special tetris-n-shapes tetris-n-rows
@@ -207,7 +207,7 @@
   "*Set this to a convenient value so you get time to look at what is
 going on. Reduce it as you get better.")
 
-(defsubst emacspeak-tetris-tick-period ()
+(defun emacspeak-tetris-tick-period ()
   (declare (special emacspeak-tetris-tick-period))
   emacspeak-tetris-tick-period)
 
@@ -339,7 +339,8 @@ concentration and the game is a good mental challenge. "
     (emacspeak-tetris-define-pronunciations)
     (emacspeak-tetris-define-keys)
     (emacspeak-tetris-speak-current-shape)
-    (goto-line tetris-height)
+    (goto-char (point-min))
+    (forward-line tetris-height)
     (message "Welcome to tetris!")))
 
 (defadvice tetris-start-game (after emacspeak pre act comp)
@@ -425,7 +426,7 @@ concentration and the game is a good mental challenge. "
   (define-key tetris-mode-map "n" 'emacspeak-self-insert-command)
   (define-key tetris-mode-map "N" 'tetris-start-game)
   (define-key  tetris-mode-map "c" 'emacspeak-tetris-speak-row)
-  (loop for i from 0 to 9
+  (cl-loop for i from 0 to 9
         do
         (define-key tetris-mode-map
           (format "%s" i)
@@ -536,7 +537,7 @@ concentration and the game is a good mental challenge. "
   (let ((result nil))
     (setq x (+ tetris-top-left-x x))
     (setq result
-          (loop for y from tetris-top-left-y
+          (cl-loop for y from tetris-top-left-y
                 to (+ tetris-height tetris-top-left-y)
                 collect (gamegrid-get-cell x y)))
     (mapconcat 'char-to-string result "")))
