@@ -118,7 +118,7 @@ instead of the modeline."
         (byte-compile '(lambda (form name)
                          (w3m-form-get form name)))))
 
-(defsubst emacspeak-w3m-personalize-string (string personality)
+(defun emacspeak-w3m-personalize-string (string personality)
   (let ((newstring (copy-sequence string)))
     (put-text-property 0 (length newstring)
                        'personality personality
@@ -158,7 +158,7 @@ instead of the modeline."
              anchor-text)
         (save-excursion
           (goto-char start)
-          (loop do
+          (cl-loop do
                 (when (and (integerp value-at-start) (not value-at-pos))
                   (push (buffer-substring start pos) anchor-text)
                   (push " " anchor-text)
@@ -290,7 +290,7 @@ instead of the modeline."
 ;;}}}
 ;;{{{  advice interactive commands:
 
-(loop for f in
+(cl-loop for f in
       '(w3m-print-current-url  w3m-print-this-url
                                w3m-search
                                w3m-edit-current-url w3m-edit-this-url)
@@ -306,7 +306,7 @@ instead of the modeline."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'button)))
 
-(loop for f in
+(cl-loop for f in
       '(w3m-previous-buffer w3m-next-buffer
                             w3m-view-next-page w3m-view-previous-page
                             w3m-view-parent-page w3m-gohome)
@@ -358,7 +358,7 @@ instead of the modeline."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'save-object)))
 
-(loop for f in
+(cl-loop for f in
       '(w3m-next-anchor w3m-previous-anchor
                         w3m-next-image w3m-previous-image
                         w3m-next-form w3m-previous-form)
@@ -423,7 +423,7 @@ instead of the modeline."
       ad-do-it))
    (t ad-do-it))ad-return-value)
 
-(loop for f in
+(cl-loop for f in
       '(w3m-scroll-up-or-next-url
         w3m-scroll-down-or-previous-url w3m-scroll-left
         w3m-shift-left w3m-shift-right
