@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2015, T. V. Raman
+;;;Copyright (C) 1995 -- 2017, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -78,11 +78,11 @@
 (defvar emacspeak-websearch-table (make-hash-table)
   "Table holding mapping from search engine names to appropriate searcher functions.")
 
-(defsubst emacspeak-websearch-set-searcher  (engine searcher)
+(defun emacspeak-websearch-set-searcher  (engine searcher)
   (declare (special emacspeak-websearch-table))
   (setf (gethash engine emacspeak-websearch-table) searcher))
 
-(defsubst emacspeak-websearch-get-searcher (engine)
+(defun emacspeak-websearch-get-searcher (engine)
   (declare (special emacspeak-websearch-table))
   (gethash engine emacspeak-websearch-table))
 
@@ -92,11 +92,11 @@
 (defvar emacspeak-websearch-keytable (make-hash-table)
   "Table holding mapping from keys to appropriate search engine names.")
 
-(defsubst emacspeak-websearch-set-key  (key engine)
+(defun emacspeak-websearch-set-key  (key engine)
   (declare (special emacspeak-websearch-keytable))
   (setf (gethash key emacspeak-websearch-keytable) engine))
 
-(defsubst emacspeak-websearch-get-engine (key)
+(defun emacspeak-websearch-get-engine (key)
   (declare (special emacspeak-websearch-keytable))
   (gethash key emacspeak-websearch-keytable))
 
@@ -106,7 +106,7 @@
 (defun emacspeak-websearch-help ()
   "Displays key mapping used by Emacspeak Websearch."
   (interactive)
-  (let ((map (loop for key being the hash-keys of
+  (let ((map (cl-loop for key being the hash-keys of
                    emacspeak-websearch-keytable
                    collect
                    (cons key (gethash key emacspeak-websearch-keytable)))))
@@ -118,7 +118,7 @@
       (save-excursion
         (set-buffer "*Help*")
         (princ "Websearch Keys:\n\n")
-        (loop for m in map
+        (cl-loop for m in map
               do
               (princ (key-description (list (car m))))
               (move-to-column 16)
@@ -128,7 +128,7 @@
               (princ "\n"))
         (help-setup-xref
          (list #'emacspeak-websearch-help)
-         (ems-interactive-p))))
+         (called-interactively-p 'interactive))))
     (pop-to-buffer "*Help*")
     (help-mode)
     (goto-char (point-min))
@@ -165,7 +165,7 @@ When using supported browsers,  this interface attempts to speak the most releva
 (defvar emacspeak-websearch-history nil
   "Holds history of search queries.")
 
-(defsubst emacspeak-websearch-read-query (prompt &optional
+(defun emacspeak-websearch-read-query (prompt &optional
                                                  default
                                                  initial)
   (let ((answer
@@ -564,7 +564,7 @@ Optional second arg as-html processes the results as HTML rather than data."
   "www.google.com/search?source=hp&q="
   "*URI for Google search")
 
-(defsubst emacspeak-websearch-google-uri ()
+(defun emacspeak-websearch-google-uri ()
   "Return URI end-point for Google search."
   (declare (special emacspeak-websearch-google-use-https
                     emacspeak-websearch-google-uri-template))
