@@ -5,7 +5,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2015, T. V. Raman 
+;;;Copyright (C) 1995 -- 2017, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -42,6 +42,19 @@
 (require 'acss-structure)
 (require 'tts)
 
+;;}}}
+;;{{{ Customizations:
+;;;###autoload
+(defcustom espeak-default-speech-rate 175
+  "Default speech rate for eSpeak."
+  :group 'tts
+  :type 'integer
+  :set #'(lambda(sym val)
+           (set-default sym val)
+           (when (and (getenv "DTK_PROGRAM")
+                      (string-match "espeak$" (getenv "DTK_PROGRAM")))
+             (setq-default dt-speech-rate val))))
+
 ;;}}}
 ;;{{{ Top-Level TTS Call
 
@@ -66,14 +79,14 @@
   "Association between symbols and strings to set Espeak  voices.
 The string can set any voice parameter.")
 
-(defsubst espeak-define-voice (name command-string)
+(defun espeak-define-voice (name command-string)
   "Define an Espeak  voice named NAME.
 This voice will be set   by sending the string
 COMMAND-STRING to the TTS engine."
   (declare (special espeak-voice-table))
   (puthash name command-string espeak-voice-table))
 
-(defsubst espeak-get-voice-command  (name)
+(defun espeak-get-voice-command  (name)
   "Retrieve command string for  voice NAME."
   (declare (special espeak-voice-table))
   (cond
@@ -82,7 +95,7 @@ COMMAND-STRING to the TTS engine."
    (t (or  (gethash name espeak-voice-table)
            espeak-default-voice-string))))
 
-(defsubst espeak-voice-defined-p (name)
+(defun espeak-voice-defined-p (name)
   "Check if there is a voice named NAME defined."
   (declare (special espeak-voice-table))
   (gethash name espeak-voice-table))
@@ -114,7 +127,7 @@ COMMAND-STRING to the TTS engine."
 
 ;;{{{ voice family codes
 
-(defsubst espeak-get-family-code (_name)
+(defun espeak-get-family-code (_name)
   "Get control code for voice family NAME."
   "")
 
@@ -126,7 +139,7 @@ COMMAND-STRING to the TTS engine."
 Keys are symbols of the form <FamilyName-Dimension>.
 Values are vectors holding the control codes for the 10 settings.")
 
-(defsubst espeak-css-set-code-table (family dimension table)
+(defun espeak-css-set-code-table (family dimension table)
   "Set up voice FAMILY.
 Argument DIMENSION is the dimension being set,
 and TABLE gives the values along that dimension."
@@ -134,7 +147,7 @@ and TABLE gives the values along that dimension."
   (let ((key (intern (format "%s-%s" family dimension))))
     (puthash key table espeak-css-code-tables)))
 
-(defsubst espeak-css-get-code-table (family dimension)
+(defun espeak-css-get-code-table (family dimension)
   "Retrieve table of values for specified FAMILY and DIMENSION."
   (declare (special espeak-css-code-tables))
   (let ((key (intern (format "%s-%s" family dimension))))
@@ -226,7 +239,7 @@ and TABLE gives the values along that dimension."
 
 ;;}}}
 
-(defsubst espeak-get-average-pitch-code (value family)
+(defun espeak-get-average-pitch-code (value family)
   "Get  AVERAGE-PITCH for specified VALUE and  FAMILY."
   (or family (setq family 'paul))
   (if value
@@ -311,7 +324,7 @@ and TABLE gives the values along that dimension."
   (espeak-css-set-code-table 'betty 'pitch-range table))
 
 ;;}}}
-(defsubst espeak-get-pitch-range-code (value family)
+(defun espeak-get-pitch-range-code (value family)
   "Get pitch-range code for specified VALUE and FAMILY."
   (or family (setq family 'paul))
   (if value
@@ -324,7 +337,7 @@ and TABLE gives the values along that dimension."
 
 ;;;  Not implemented fo Espeak now.
 
-(defsubst espeak-get-stress-code (_value _family)
+(defun espeak-get-stress-code (_value _family)
   "Just a dummy."
   "")
 
@@ -414,7 +427,7 @@ and TABLE gives the values along that dimension."
 
 ;;}}}
 
-(defsubst espeak-get-richness-code (value family)
+(defun espeak-get-richness-code (value family)
   (or family (setq family 'paul))
   (if value 
       (aref (espeak-css-get-code-table family 'richness)
@@ -424,7 +437,7 @@ and TABLE gives the values along that dimension."
 ;;}}}
 ;;{{{  punctuations
 
-(defsubst espeak-get-punctuations-code (_value)
+(defun espeak-get-punctuations-code (_value)
   "Return string needed to set specified punctuations mode."
   "")
 
@@ -455,7 +468,7 @@ and TABLE gives the values along that dimension."
 (defun espeak-list-voices ()
   "List defined voices."
   (declare (special espeak-voice-table))
-  (loop for k being the hash-keys of espeak-voice-table 
+  (cl-loop for k being the hash-keys of espeak-voice-table 
         collect   k))
 
 ;;}}}
@@ -470,7 +483,7 @@ and TABLE gives the values along that dimension."
              (vectorp dtk-character-to-speech-table))
     (setq espeak-character-to-speech-table
           (let ((table (copy-seq dtk-character-to-speech-table)))
-            (loop for entry across-ref table 
+            (cl-loop for entry across-ref table 
                   when   (string-match "\\(\\[\\*\\]\\)"  entry) do
                   (setf entry (replace-match " " nil nil  entry 1)))
             table))))
